@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: utils.c 4841 2008-01-27 16:08:22Z charles $
+ * $Id: utils.c 5010 2008-02-13 01:21:23Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -68,7 +68,7 @@ tr_getLog( void )
     if( !initialized )
     {
         const char * str = getenv( "TR_DEBUG_FD" );
-        int fd;
+        int fd = 0;
         if( str && *str )
             fd = atoi( str );
         switch( fd ) {
